@@ -45,4 +45,7 @@ enum ofono_vendor {
 	OFONO_VENDOR_ALCATEL,
 	OFONO_VENDOR_QUECTEL,
 	OFONO_VENDOR_UBLOX,
+	OFONO_VENDOR_UBLOX_TOBY_L2,
+	OFONO_VENDOR_CINTERION,
+	OFONO_VENDOR_XMM,
 };
