@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
+ *  Copyright (C) 2009-2010  Nokia Corporation and/or its subsidiary(-ies).
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -163,7 +163,8 @@ static void pending_remove_and_dispatch(GIsiPending *op, GIsiMessage *msg)
 	modem = op->service->modem;
 
 	ISIDBG(modem, "%s %s to %p [res=0x%02X, id=0x%02X, utid=0x%02X]",
-		g_isi_msg_strerror(msg), pend_type_to_str(op->type), op,
+		g_isi_msg_error(msg) ? g_isi_msg_strerror(msg) : "normal",
+		pend_type_to_str(op->type), op,
 		g_isi_msg_resource(msg), g_isi_msg_id(msg),
 		g_isi_msg_utid(msg));
 
@@ -252,11 +253,11 @@ static void common_message_decode(GIsiServiceMux *mux, GIsiMessage *msg)
 		}
 		/* fall through */
 
-	case 0x00:
+	default:
 		/*
 		 * PN_SIM doesn't support ISI version, but sends a
-		 * 0x00 message as a response.  Work around this modem
-		 * wart.
+		 * garbage message as a response. Work around this
+		 * modem wart.
 		 */
 		mux->object = g_isi_msg_object(msg);
 		mux->version_pending = FALSE;
