@@ -167,7 +167,7 @@ static gboolean radio_band_umts_from_string(const char *str,
 					enum ofono_radio_band_umts *band)
 {
 	if (g_str_equal(str, "any")) {
-		*band = OFONO_RADIO_BAND_GSM_ANY;
+		*band = OFONO_RADIO_BAND_UMTS_ANY;
 		return TRUE;
 	} else if (g_str_equal(str, "850")) {
 		*band = OFONO_RADIO_BAND_UMTS_850;
@@ -856,9 +856,13 @@ static void radio_load_settings(struct ofono_radio_settings *rs,
 						"GsmBand", rs->band_gsm);
 	}
 
+	if (error) {
+		g_error_free(error);
+		error = NULL;
+	}
+
 	rs->pending_band_gsm = rs->band_gsm;
 
-	error = NULL;
 	rs->band_umts = g_key_file_get_integer(rs->settings, SETTINGS_GROUP,
 					"UmtsBand", &error);
 
@@ -868,9 +872,13 @@ static void radio_load_settings(struct ofono_radio_settings *rs,
 						"UmtsBand", rs->band_umts);
 	}
 
+	if (error) {
+		g_error_free(error);
+		error = NULL;
+	}
+
 	rs->pending_band_umts = rs->band_umts;
 
-	error = NULL;
 	rs->mode = g_key_file_get_integer(rs->settings, SETTINGS_GROUP,
 					"TechnologyPreference", &error);
 
@@ -880,6 +888,11 @@ static void radio_load_settings(struct ofono_radio_settings *rs,
 					"TechnologyPreference", rs->mode);
 	}
 
+	if (error) {
+		g_error_free(error);
+		error = NULL;
+	}
+
 	DBG("TechnologyPreference: %d", rs->mode);
 	DBG("GsmBand: %d", rs->band_gsm);
 	DBG("UmtsBand: %d", rs->band_umts);
